@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Ryu::Node);
 
-our $VERSION = '1.010'; # VERSION
+our $VERSION = '1.011'; # VERSION
 
 =head1 NAME
 
@@ -28,6 +28,7 @@ point.
 
 no indirect;
 
+use sort qw(stable);
 use Scalar::Util ();
 use Ref::Util ();
 use List::Util ();
@@ -1016,9 +1017,18 @@ sub switch_str {
 =head2 ordered_futures
 
 Given a stream of L<Future>s, will emit the results as each L<Future>
-is marked ready. If any fail, the stream will fail.
+is marked ready.
 
-This is a terrible name for a method, expect it to change.
+If any L<Future> in the stream fails, that will mark this source as failed,
+and all remaining L<Future> instances will be cancelled. To avoid this behaviour
+and leave the L<Future> instances active, use:
+
+ $src->map('without_cancel')
+     ->ordered_futures
+
+See L<Future/without_cancel> for more details.
+
+This method is also available as L</resolve>.
 
 =cut
 
@@ -1026,30 +1036,43 @@ sub ordered_futures {
     my ($self) = @_;
     my $src = $self->chained(label => (caller 0)[3] =~ /::([^:]+)$/);
     my %pending;
-    Scalar::Util::weaken(my $upstream_completed = $self->completed);
+    my $src_completed = $src->completed;
     my $all_finished = 0;
-    $upstream_completed->on_ready(sub {
+    $self->completed->on_ready(sub {
         $all_finished = 1;
-        $src->completed->done unless %pending or $src->completed->is_ready;
+        $src->completed->done unless %pending or $src_completed->is_ready;
     });
 
     $self->each(sub {
         my $k = Scalar::Util::refaddr $_;
         $pending{$k} = 1;
         $log->tracef('Ordered futures has %d pending', 0 + keys %pending);
-        $_->on_done($src->curry::weak::emit)
-          ->on_fail($src->curry::weak::fail)
+        my $f = $_;
+        $src_completed->on_ready(sub { $f->cancel });
+        $_->on_done(sub {
+            my @pending = @_;
+            while(@pending and not $src_completed->is_ready) {
+                $src->emit(shift @pending);
+            }
+        })
+          ->on_fail(sub { $src->fail(@_) unless $src_completed->is_ready; })
           ->on_ready(sub {
               delete $pending{$k};
               $log->tracef('Ordered futures now has %d pending after completion, upstream finish status is %d', 0 + keys(%pending), $all_finished);
               return if %pending;
-              $src->completed->done if $all_finished and not $src->completed->is_ready;
+              $src_completed->done if $all_finished and not $src_completed->is_ready;
           })
           ->retain
     });
     return $src;
 }
 
+=head2 resolve
+
+A synonym for L</ordered_futures>.
+
+=cut
+
 *resolve = *ordered_futures;
 
 =head2 concurrent
@@ -1202,7 +1225,6 @@ See L</sort_by>.
 =cut
 
 sub rev_nsort_by {
-    use sort qw(stable);
     my ($self, $code) = @_;
     my $src = $self->chained(label => (caller 0)[3] =~ /::([^:]+)$/);
     my @items;
@@ -2035,5 +2057,5 @@ Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2011-2019. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2011-2020. Licensed under the same terms as Perl itself.
 
